Learn R Programming

spectralAnomaly (version 0.1.1)

spectralAnomaly-package: spectralAnomaly: Detect Anomalies Using the Spectral Residual Algorithm

Description

logo

Apply the spectral residual algorithm to data, such as a time series, to detect anomalies. Anomaly scores can be used to determine outliers based upon a threshold or fed into more sophisticated prediction models. Methods are based upon "Time-Series Anomaly Detection Service at Microsoft", Ren, H., Xu, B., Wang, Y., et al., (2019) tools:::Rd_expr_doi("10.48550/arXiv.1906.03821").

Arguments

Author

Maintainer: Allen OBrien allen.g.obrien@gmail.com [copyright holder]

See Also